Module futures

Module futures 

Futures returned by middleware.

Re-exports

pub use defined::DefinedFuture;
pub use undefined::UndefinedFuture;

Modules

defined
A future defined at the time the middleware is called.
undefined
A future that is defined by the result of a future.