Module undefined

Module undefined 

A future that is defined by the result of a future.

Structs

UndefinedFuture
A future that is defined by the result of a future.

Traits

DefiningFuture
Trait alias for the future that defined the final response.